tietools.get_tie_spanner_attached_to_component
==============================================

.. autofunction:: abjad.tools.tietools.get_tie_spanner_attached_to_component.get_tie_spanner_attached_to_component
   :noindex:
